@@ -32,5 +32,5 @@ def publish_to_facebook(user, contents):
         "message": unicode(contents).encode('utf-8'),
     }
     result = facebook_request(url, token, data=data)
-    print result
+    return result
 
